SXDM Documentation — sxdm v0.5 documentation

# SXDM documentation

Python library for analyzing Scanning X-Ray Diffraction Microscopy data.

Warning

This documentation and the code are under active development. We make every effort to ensure the code is usable, but make no guarantees.

Contents:

- Introduction
  - Installation
  - Development
  - Scanning X-Ray Diffraction Microscopy
  - Example Workflow
- Importing Data into SXDM
  - APS Beamline 26-ID-C
- Analyzing the Data
  - Setting Up Detector Channels
  - Setting Up Frameset
  - Initial Values
  - Scan Dimensions Check
  - Alignment
  - Diffraction Axis Values
  - Region Of Interest Analysis
  - Centroid Analysis
  - Retrieving Imported Data
- Visualization of Results
  - Region of Interest Viewer
  - Centroid Analysis Viewer
  - Return Raw Centroid Map Values
  - Make New Bound For Centroid Maps

# Indices and tables

- Index

- Module Index

- Search Page